===============================================
py-hplc |build-status| |docs| |pylint| |style| 
===============================================

Overview
==========
An unoffical Python wrapper for the SSI-Teledyne Next Generation class HPLC pumps.

- `Download page`_ 
- `API Documentation`_
- `Official pump documentation`_

MIT license, (C) 2021 Alex Whittington <alex@southsun.tech>

Installation
=============
The package is available on PyPI.

``python -m pip install py-hplc``

.. _`Download page`: https://pypi.org/project/py-hplc/
.. _`API Documentation`: https://py-hplc.readthedocs.io/en/latest/
.. _`Official pump documentation`: https://www.teledynessi.com/Manuals%20%20Guides/Product%20Guides%20and%20Resources/Serial%20Pump%20Control%20for%20Next%20Generation%20SSI%20Pumps.pdf


.. |build-status| image:: https://github.com/teauxfu/py-hplc/actions/workflows/build.yml/badge.svg
  :target: https://github.com/teauxfu/py-hplc/actions/workflows/build.yml
  :alt: Build Status

.. |docs| image:: https://readthedocs.org/projects/pip/badge/?version=stable
  :target: https://pip.pypa.io/en/stable/?badge=stable
  :alt: Documentation Status

.. |style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :target: https://github.com/psf/black
  :alt: Style
  
.. |pylint| image:: https://mperlet.github.io/pybadge/badges/9.86.svg
  :target: https://github.com/mperlet/pybadge
  :alt: Vanilla Pylint Score
